#!/bin/bash

if [ -z "$RPM_BUILD_ROOT" -o "$RPM_BUILD_ROOT" = "/" ]; then
	echo "ERROR: no RPM_BUILD_ROOT"
	exit 1
fi
if [ -z "$TARGET_NAME" ]; then
	echo "ERROR: no TARGET_NAME"
	exit 1
fi
if [ -z "$TARGET_PRFIX" -o "$TARGET_PRFIX" = "/" ]; then
	echo "ERROR: no TARGET_PRFIX"
	exit 1
fi
if [ -z "$TARGET_CROSS_PRFIX" -o "$TARGET_CROSS_PRFIX" = "/" ]; then
	echo "ERROR: no TARGET_CROSS_PRFIX"
	exit 1
fi

echo "+++ CROSS FILE START +++"
echo ${TARGET_CROSS_PRFIX}${TARGET_PRFIX}

#echo $1
#echo $RPM_BUILD_ROOT
#echo $TARGET_NAME
#echo $TARGET_PRFIX
#echo $TARGET_CROSS_PRFIX

PRFIX_DIR="${RPM_BUILD_ROOT}${TARGET_PRFIX}"



# Compress man pages
COMPRESS="gzip -9 -n"
COMPRESS_EXT=.gz

function cross_strip_static() {
  for f in `find "$RPM_BUILD_ROOT" -type f -a -exec file {} \; | \
	grep 'current ar archive' | \
	sed -n -e 's/^\(.*\):[ 	]*current ar archive/\1/p'`; do
	$TARGET_NAME-strip -g "$f"
	echo "-g ${f#$RPM_BUILD_ROOT/*}"
  done
}

function cross_strip_bin() {
  for f in `find "$RPM_BUILD_ROOT" -type f \( -perm -0100 -or -perm -0010 -or -perm -0001 \) -exec file {} \; | \
	grep -v ' shared object,' | \
	sed -n -e 's/^\(.*\):[ 	].*ELF.*, not stripped/\1/p'`; do
	$TARGET_NAME-strip -s "$f" || :
	echo "-s ${f#$RPM_BUILD_ROOT/*}"
  done
}

function cross_strip_comment() {
  for f in `find "$RPM_BUILD_ROOT" -type f \( -perm -0100 -or -perm -0010 -or -perm -0001 \) -exec file {} \; | \
	sed -n -e 's/^\(.*\):[ 	].*ELF.*, stripped/\1/p'`; do
	note="-R .note"
	if $TARGET_NAME-objdump -h $f | grep '^[ 	]*[0-9]*[ 	]*.note[ 	]' -A 1 | \
		grep ALLOC >/dev/null; then
		note=
	fi
	$TARGET_NAME-strip -R .comment $note "$f" || :
	echo "-R .comment $note ${f#$RPM_BUILD_ROOT/*}"
  done
}

function man_compress() {

  for d in $PRFIX_DIR/share/man/man* $PRFIX_DIR/share/info; do

    [ -d $d ] || continue
    for f in `find $d -type f`
    do
        [ -f "$f" ] || continue
	[ "`basename $f`" = "dir" ] && continue

	case "$f" in
	 *.gz|*.Z)    gunzip  $f; b=`echo $f | sed -e 's/\.\(gz\|Z\)$//'`;;
	 *.bz2)       bunzip2 $f; b=`echo $f | sed -e 's/\.bz2$//'`;;
	 *.xz|*.lzma) unxz    $f; b=`echo $f | sed -e 's/\.\(xz\|lzma\)$//'`;;
	 *) b=$f;;
	esac

#    echo "man_compress $b"
	echo "- ${b#$RPM_BUILD_ROOT/*}"

	$COMPRESS $b </dev/null 2>/dev/null || {
	    inode=`ls -i $b | awk '{ print $1 }'`
	    others=`find $d -type f -inum $inode`
	    if [ -n "$others" ]; then
		for afile in $others ; do
		    [ "$afile" != "$b" ] && rm -f $afile
		done
		$COMPRESS -f $b
		for afile in $others ; do
		    [ "$afile" != "$b" ] && ln $b$COMPRESS_EXT $afile$COMPRESS_EXT
		done
	    else
		$COMPRESS -f $b
	    fi
	}
    done

    for f in `find $d -type l`
    do
	l=`ls -l $f | sed -e 's/.* -> //' -e 's/\.\(gz\|Z\|bz2\|xz\|lzma\)$//'`
	rm -f $f
	b=`echo $f | sed -e 's/\.\(gz\|Z\|bz2\|xz\|lzma\)$//'`
	ln -sf $l$COMPRESS_EXT $b$COMPRESS_EXT
    done
  done
}

echo "+++ strip_bin +++"
cross_strip_bin
echo "+++ strip_comment +++"
cross_strip_comment
echo "+++ strip_static +++"
cross_strip_static
echo "+++ man_compress +++"
man_compress

echo "+++ copy data +++"
SRC_DIR=

pushd $RPM_BUILD_ROOT >/dev/null
for i in *; do
  SRC_DIR="$SRC_DIR$i "
done

if test ! -d ${RPM_BUILD_ROOT}${TARGET_CROSS_PRFIX}; then
  echo "mkdir -p ${RPM_BUILD_ROOT}${TARGET_CROSS_PRFIX}"
  mkdir -p ${RPM_BUILD_ROOT}${TARGET_CROSS_PRFIX}
fi

pushd $RPM_BUILD_ROOT >/dev/null
for i in $SRC_DIR; do
  echo "cp -r $i ${RPM_BUILD_ROOT}${TARGET_CROSS_PRFIX}/"
  cp -r $i ${RPM_BUILD_ROOT}${TARGET_CROSS_PRFIX}/
done

popd >/dev/null
echo "+++ CROSS FILE END +++"


